==> viha-5.15.tar.gz: viha-5.15/tavara.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "tavara";
$file = basename(__FILE__);

include "common.php";
include "tavara-ok.php";

echo "
<html>
<head>
 <title>VIHA - Kalusto</title>
</head>
" . body_bgcolor() . "
<h1>" . ota_paivystys_nimi() . ", kaluston ksittely</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$tavara_tyyppi_id = get_nro_1('tavara_tyyppi_id');
$jarjesto_id = get_nro_1('jarjesto_id');
$hlo_id = get_nro_0('hlo_id');
$tavara = get_txt('tavara');
$tunniste = get_txt('tunniste');
$selite = get_txt('selite');
$vara_akut = get_nro_0('vara_akut');
$palaute = get_txt('palaute');
$ryhma_id = get_nro_1('ryhma_id');
$merkitty = get_nro_0('merkitty');
$vakuutettu = get_nro_0('vakuutettu');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

oltava_sallittu($file,$table,$id);

if (($add != '') && saa_tehda("$file:add")) {
  $ret = tavara_add_ok($herja,s('alue'),
		       s('paivystys'),
		       $jarjesto_id,$hlo_id,$tavara,
		       $tunniste,$ryhma_id,$tavara_tyyppi_id,
		       $merkitty,$vakuutettu);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO $table
       SET alue_id = " . s("alue") . ",
           paivystys_id = " . s("paivystys") . ",
           tavara_tyyppi_id = $tavara_tyyppi_id,
           jarjesto_id = $jarjesto_id,
           hlo_id = $hlo_id,
           tavara = '$tavara',
           tunniste = '$tunniste',
           selite = '$selite',
           palaute = '$palaute',
           ryhma_id = $ryhma_id,
           merkitty = $merkitty,
           vakuutettu = $vakuutettu,
           ts = '$now'";
    $result = my_mysql_query ($sql);
    print "<p>Tiedot listty.\n";
    $clear = "ADD";
    loki("$sql id=" . last_insert_id());
    taktinen_loki("Listty tavara $tavara ($tunniste)");
  }
  p_herja($ret,$herja);
} # add

if (($save != '') && saa_tehda("$file:save")) {
  $ret = tavara_save_ok($herja,$id,s('alue'),
			s('paivystys'),
			$jarjesto_id,$hlo_id,
			$tavara,$tunniste,$ryhma_id,$tavara_tyyppi_id,
			$merkitty,$vakuutettu);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE $table
       SET alue_id = " . s("alue") . ",
           paivystys_id = " . s("paivystys") . ",
           tavara_tyyppi_id = $tavara_tyyppi_id,
           jarjesto_id = $jarjesto_id,
           hlo_id = $hlo_id,
           tavara = '$tavara',
           tunniste = '$tunniste',
           selite = '$selite',
           palaute = '$palaute',
           ryhma_id = $ryhma_id,
           merkitty = $merkitty,
           vakuutettu = $vakuutettu,
           ts = '$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql);
    print "<p>Tiedot pivitetty.\n";
    loki($sql);
    taktinen_loki("Muutettu tavaraa $tavara ($tunniste)");
  }
  p_herja($ret,$herja);
 } # save

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = tavara_remove_ok($herja,$id,true);
  if ($ret != 2) {
    $tavara = tab_col_id("tavara","",$id);
    $tunniste = tab_col_id("tavara","tunniste",$id);
    taktinen_loki("Poistetaan tavaraa $tavara ($tunniste)");
    $now = date('Y-m-d H:i:s');
    $sql = "DELETE FROM $table WHERE id = $id";
    $result = my_mysql_query ($sql);
    print "<p>Tiedot poistettu.\n";
    $clear = "SISINEN";
    loki($sql);
  }
  p_herja($ret,$herja);
 } # confirm

if ($clear != '') {
  $id = '0';
  $tavara_tyyppi_id = '1';
  $jarjesto_id = '1';
  $hlo_id = '0';
  $tavara = '';
  $tunniste = '';
  $selite = '';
  $palaute = '';
  $ryhma_id = '1';
  $merkitty = '0';
  $vakuutettu = '0';
 }

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = tavara_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
}

print "<form action=\"\" method=\"GET\">\n";
print "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $tavara_tyyppi_id = $a['tavara_tyyppi_id'];
  $paivystys_id = $a['paivystys_id'];
  $jarjesto_id = $a['jarjesto_id'];
  $hlo_id = $a['hlo_id'];
  $tavara = $a['tavara'];
  $tunniste = $a['tunniste'];
  $selite = $a['selite'];
  $palaute = $a['palaute'];
  $ryhma_id = $a['ryhma_id'];
  $merkitty = $a['merkitty'];
  $vakuutettu = $a['vakuutettu'];
}

print "<tr><td>Id:";
if ($id == "0") {
  print "<td>(tehdn uusi)\n";
} else {
  print "<td>$id\n";
}
print "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
print " value=\"$id\">\n";

print "<tr><td>Tavaran tyyppi:";
if ($readonly) {
  print "<td>" . tab_col_id("tavara_tyyppi","",$tavara_tyyppi_id) . "\n";
} else {
  print "<td>\n";
  tee_valinta("tavara_tyyppi_id", $tavara_tyyppi_id, "tavara_tyyppi", "id",
	      "tavara_tyyppi", "ORDER BY tavara_tyyppi");
}

print "<tr><td>Jrjest:";
if ($readonly) {
  print "<td>" . tab_col_id("jarjesto","",$jarjesto_id) . "\n";
} else {
  print "<td>\n";
  tee_valinta("jarjesto_id", $jarjesto_id, "jarjesto", "id",
	      "jarjesto", "ORDER BY jarjesto");
}

print "<tr><td>Yhdyshenkil:";
if ($readonly) {
  print "<td>"
  . ota_yksi_0("SELECT nimi FROM hlo WHERE id = $hlo_id",
	       $hlo_id, "EI KUKAAN")
  . "\n";
} else {
  print "<td>\n";
  tee_valinta_plus_0("hlo_id", $hlo_id, "hlo", "id",
		     "nimi", "ORDER BY nimi", "EI MIKN");
  echo " Tai omistaja, ellei tavaralle ole mritelty jrjest";
}

print "<tr><td>Kuvaus:";
if ($readonly) {
  print "<td>$tavara\n";
} else {
  print "<td><input type=\"text\" name=\"tavara\" size=32 maxlength=32";
  print " value=\"$tavara\">\n";
}

print "<tr><td>Tunniste:";
if ($readonly) {
  print "<td>$tunniste\n";
} else {
  print "<td><input type=\"text\" name=\"tunniste\" size=32 maxlength=32";
  print " value=\"$tunniste\"> Sarjanumero, juokseva numero tms.\n";
}

print "<tr><td>Listietoja:";
if ($readonly) {
  print "<td>$selite\n";
} else {
  print "<td><input type=\"text\" name=\"selite\" size=64 maxlength=64";
  print " value=\"$selite\">\n";
}

print "<tr><td>Palaute:";
if ($readonly) {
  print "<td>$palaute\n";
} else {
  print "<td><input type=\"text\" name=\"palaute\" size=64 maxlength=255";
  print " value=\"$palaute\">\n";
}

print "<tr><td>Ryhm:";
if ($readonly) {
  print "<td>"
    . ota_yksi("SELECT kutsu FROM ryhma WHERE id = $ryhma_id")
    . "\n";
} else {
  print "<td>\n";
  select_ryhma($ryhma_id);
}

print "<tr><td>Merkitty:";
if ($readonly) {
  print "<td>" . tab_col_id("juuei","",$merkitty) . "\n";
} else {
  print "<td>\n";
  tee_valinta("merkitty", $merkitty, "juuei", "id", "juuei", "ORDER BY juuei");
}

print "<tr><td>Vakuutettu:";
if ($readonly) {
  print "<td>" . tab_col_id("juuei","",$vakuutettu) . "\n";
} else {
  print "<td>\n";
  tee_valinta("vakuutettu", $vakuutettu, "juuei", "id", "juuei",
	      "ORDER BY juuei");
}

print "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
 } elseif ($remove != "") {
  if ($removable) {
    echo "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
 } else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
 }

$sql =
  "SELECT $table.id, $table.ts, $table.tavara, $table.tunniste,
          $table.selite,
          jarjesto.jarjesto, paivystys.nimi AS pnimi,
          hlo_id, ryhma.kutsu, merkitty, vakuutettu,
          tavara_tyyppi.tavara_tyyppi, palaute
   FROM $table,jarjesto,ryhma,tavara_tyyppi,paivystys
   WHERE $table.jarjesto_id = jarjesto.id
         AND $table.ryhma_id = ryhma.id
         AND $table.tavara_tyyppi_id = tavara_tyyppi.id
         AND $table.paivystys_id = paivystys.id
   ORDER BY $table.tavara, $table.tunniste";
$result = my_mysql_query($sql);
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  echo tr_bgcolor()
    . "<TH>Id<TH>Aikaleima<TH>Operaatio<TH>Kuvaus<TH>Tunniste<TH>Selite"
    . "<TH>Jrjest<TH>Henkil<TH>Ryhm"
    . "<TH>Merk<TH>Vak<TH>Tyyppi<TH>Palaute\n";
  while ($a = mysql_fetch_array($result)) {
    # just skip those items we do not have permission to
    if (visible_admin_tab($herja,$table,$a['id'],false) == 2)
      continue; 
    echo "<TR><TD>$a[id]",
      "<TD>$a[ts]",
      "<TD>$a[pnimi]",
      "<TD>$a[tavara]",
      "<TD>$a[tunniste]",
      "<TD>$a[selite]",
      "<TD>$a[jarjesto]",
      "<TD>" . tab_col_id_nobody("hlo","nimi",$a['hlo_id']),
      "<TD>$a[kutsu]",
      "<TD>" . tab_col_id("juuei","",$a['merkitty']),
      "<TD>" . tab_col_id("juuei","",$a['vakuutettu']),
      "<TD>$a[tavara_tyyppi]",
      "<TD>$a[palaute]";
    if ($id == "0") {
      echo "<td><a href=\"$file?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
      echo "<td><a href=\"$file?id=$a[id]&remove=POISTA\">POISTA</a>\n";
    }
  }
  echo "</TABLE>";
 } else {
  echo "<p>Plop. Ei kalustotietoja.";
 }

print "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: tavara.php,v 1.21 2009/05/04 05:17:31 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/tavara.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "tavara";
$file = basename(__FILE__);

include "common.php";
include "tavara-ok.php";

echo "
<html>
<head>
 <title>VIHA - Kalusto</title>
</head>
" . body_bgcolor() . "
<h1>" . muotoile_operaatio() . ", kaluston ksittely</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$tavara_tyyppi_id = get_nro_1('tavara_tyyppi_id');
$jarjesto_id = get_nro_1('jarjesto_id');
$hlo_id = get_nro_0('hlo_id');
$tavara = get_txt('tavara');
$tunniste = get_txt('tunniste');
$selite = get_txt('selite');
$vara_akut = get_nro_0('vara_akut');
$palaute = get_txt('palaute');
$ryhma_id = get_nro_1('ryhma_id');
$merkitty = get_nro_0('merkitty');
$vakuutettu = get_nro_0('vakuutettu');

$add = get_txt('add');
$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

oltava_sallittu($file,$table,$id);

if (($add != '') && saa_tehda("$file:add")) {
  $ret = tavara_add_ok($herja,s('alue'),
		       s('paivystys'),
		       $jarjesto_id,$hlo_id,$tavara,
		       $tunniste,$ryhma_id,$tavara_tyyppi_id,
		       $merkitty,$vakuutettu);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "INSERT INTO $table
       SET alue_id = " . s("alue") . ",
           paivystys_id = " . s("paivystys") . ",
           tavara_tyyppi_id = $tavara_tyyppi_id,
           jarjesto_id = $jarjesto_id,
           hlo_id = $hlo_id,
           tavara = '$tavara',
           tunniste = '$tunniste',
           selite = '$selite',
           palaute = '$palaute',
           ryhma_id = $ryhma_id,
           merkitty = $merkitty,
           vakuutettu = $vakuutettu,
           ts = '$now'";
    $result = my_mysql_query ($sql);
    $new_id = last_insert_id();
    loki("$sql id=$new_id");
    $msg = "Listty tavara " . tavara_tunniste($new_id);
    $clear = "ADD";
    taktinen_loki($msg);
    tehty($msg);
  }
  p_herja($ret,$herja);
} # add

if (($save != '') && saa_tehda("$file:save")) {
  $ret = tavara_save_ok($herja,$id,s('alue'),
			s('paivystys'),
			$jarjesto_id,$hlo_id,
			$tavara,$tunniste,$ryhma_id,$tavara_tyyppi_id,
			$merkitty,$vakuutettu);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE $table
       SET alue_id = " . s("alue") . ",
           paivystys_id = " . s("paivystys") . ",
           tavara_tyyppi_id = $tavara_tyyppi_id,
           jarjesto_id = $jarjesto_id,
           hlo_id = $hlo_id,
           tavara = '$tavara',
           tunniste = '$tunniste',
           selite = '$selite',
           palaute = '$palaute',
           ryhma_id = $ryhma_id,
           merkitty = $merkitty,
           vakuutettu = $vakuutettu,
           ts = '$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql,true,true);
    $msg = "Muutettu tavaraa " . tavara_tunniste($id);
    tehty($msg);
    taktinen_loki($msg);
  }
  p_herja($ret,$herja);
 } # save

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = tavara_remove_ok($herja,$id,true);
  if ($ret != 2) {
    $msg = "Poistettu tavara " . tavara_tunniste($id);
    $now = date('Y-m-d H:i:s');
    $sql = "DELETE FROM $table WHERE id = $id";
    $result = my_mysql_query ($sql,true,true);
    $clear = "SISINEN";
    taktinen_loki($msg);
    tehty($msg);
  }
  p_herja($ret,$herja);
 } # confirm

if ($clear != '') {
  $id = '0';
  $tavara_tyyppi_id = '1';
  $jarjesto_id = '1';
  $hlo_id = '0';
  $tavara = '';
  $tunniste = '';
  $selite = '';
  $palaute = '';
  $ryhma_id = '1';
  $merkitty = '0';
  $vakuutettu = '0';
 }

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = tavara_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
}

print "<form action=\"\" method=\"GET\">\n";
print "<p><table border=0>\n";

if ($id != "0") {
  $result = my_mysql_query("SELECT * FROM $table WHERE id = $id");
  $a = mysql_fetch_array($result);
  $tavara_tyyppi_id = $a['tavara_tyyppi_id'];
  $paivystys_id = $a['paivystys_id'];
  $jarjesto_id = $a['jarjesto_id'];
  $hlo_id = $a['hlo_id'];
  $tavara = $a['tavara'];
  $tunniste = $a['tunniste'];
  $selite = $a['selite'];
  $palaute = $a['palaute'];
  $ryhma_id = $a['ryhma_id'];
  $merkitty = $a['merkitty'];
  $vakuutettu = $a['vakuutettu'];
}

print "<tr><td>Id:";
if ($id == "0") {
  print "<td>(tehdn uusi)\n";
} else {
  print "<td>$id\n";
}
print "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
print " value=\"$id\">\n";

print "<tr><td>Tavaran tyyppi:";
if ($readonly) {
  print "<td>" . tab_col_id("tavara_tyyppi","",$tavara_tyyppi_id) . "\n";
} else {
  print "<td>\n";
  tee_valinta("tavara_tyyppi_id", $tavara_tyyppi_id, "tavara_tyyppi", "id",
	      "tavara_tyyppi", "ORDER BY tavara_tyyppi");
}

print "<tr><td>Jrjest:";
if ($readonly) {
  print "<td>" . tab_col_id("jarjesto","",$jarjesto_id) . "\n";
} else {
  print "<td>\n";
  tee_valinta("jarjesto_id", $jarjesto_id, "jarjesto", "id",
	      "jarjesto", "ORDER BY jarjesto");
}

print "<tr><td>Yhdyshenkil:";
if ($readonly) {
  print "<td>"
  . ota_yksi_0("SELECT nimi FROM hlo WHERE id = $hlo_id",
	       $hlo_id, "EI KUKAAN")
  . "\n";
} else {
  print "<td>\n";
  tee_valinta_plus_0("hlo_id", $hlo_id, "hlo", "id",
		     "nimi", "ORDER BY nimi", "EI MIKN");
  echo " Tai omistaja, ellei tavaralle ole mritelty jrjest";
}

print "<tr><td>Kuvaus:";
if ($readonly) {
  print "<td>$tavara\n";
} else {
  print "<td><input type=\"text\" name=\"tavara\" size=32 maxlength=32";
  print " value=\"$tavara\">\n";
}

print "<tr><td>Tunniste:";
if ($readonly) {
  print "<td>$tunniste\n";
} else {
  print "<td><input type=\"text\" name=\"tunniste\" size=32 maxlength=32";
  print " value=\"$tunniste\"> Sarjanumero, juokseva numero tms.\n";
}

print "<tr><td>Listietoja:";
if ($readonly) {
  print "<td>$selite\n";
} else {
  print "<td><input type=\"text\" name=\"selite\" size=64 maxlength=64";
  print " value=\"$selite\">\n";
}

print "<tr><td>Palaute:";
if ($readonly) {
  print "<td>$palaute\n";
} else {
  print "<td><input type=\"text\" name=\"palaute\" size=64 maxlength=255";
  print " value=\"$palaute\">\n";
}

print "<tr><td>Ryhm:";
if ($readonly) {
  print "<td>"
    . ota_yksi("SELECT kutsu FROM ryhma WHERE id = $ryhma_id")
    . "\n";
} else {
  print "<td>\n";
  select_ryhma($ryhma_id);
}

print "<tr><td>Merkitty:";
if ($readonly) {
  print "<td>" . tab_col_id("juuei","",$merkitty) . "\n";
} else {
  print "<td>\n";
  tee_valinta("merkitty", $merkitty, "juuei", "id", "juuei", "ORDER BY juuei");
}

print "<tr><td>Vakuutettu:";
if ($readonly) {
  print "<td>" . tab_col_id("juuei","",$vakuutettu) . "\n";
} else {
  print "<td>\n";
  tee_valinta("vakuutettu", $vakuutettu, "juuei", "id", "juuei",
	      "ORDER BY juuei");
}

print "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
 } elseif ($remove != "") {
  if ($removable) {
    echo "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  }
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
 } else {
  echo "<input type=\"submit\" name=\"add\" value=\"LIS\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"TYHJENN\">\n";
 }

$sql =
  "SELECT $table.id, $table.ts, $table.tavara, $table.tunniste,
          $table.selite,
          jarjesto.jarjesto, paivystys.nimi AS pnimi,
          hlo_id, ryhma.kutsu, merkitty, vakuutettu,
          tavara_tyyppi.tavara_tyyppi, palaute
   FROM $table,jarjesto,ryhma,tavara_tyyppi,paivystys
   WHERE $table.jarjesto_id = jarjesto.id
         AND $table.ryhma_id = ryhma.id
         AND $table.tavara_tyyppi_id = tavara_tyyppi.id
         AND $table.paivystys_id = paivystys.id
   ORDER BY $table.tavara, $table.tunniste";
$result = my_mysql_query($sql);
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  tr_reset();
  echo tr_vaalsin()
    . "<TH>Id<TH>Aikaleima<TH>Operaatio<TH>Kuvaus<TH>Tunniste<TH>Selite"
    . "<TH>Jrjest<TH>Henkil<TH>Ryhm"
    . "<TH>Merk<TH>Vak<TH>Tyyppi<TH>Palaute\n";
  while ($a = mysql_fetch_array($result)) {
    # just skip those items we do not have permission to
    if (visible_admin_tab($herja,$table,$a['id'],false) == 2)
      continue; 
    echo tr() . "<TD>$a[id]",
      "<TD>$a[ts]",
      "<TD>$a[pnimi]",
      "<TD>$a[tavara]",
      "<TD>$a[tunniste]",
      "<TD>$a[selite]",
      "<TD>$a[jarjesto]",
      "<TD>" . tab_col_id_nobody("hlo","nimi",$a['hlo_id']),
      "<TD>$a[kutsu]",
      "<TD>" . tab_col_id("juuei","",$a['merkitty']),
      "<TD>" . tab_col_id("juuei","",$a['vakuutettu']),
      "<TD>$a[tavara_tyyppi]",
      "<TD>$a[palaute]";
    if ($id == "0") {
      echo "<td><a href=\"$file?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
      echo "<td><a href=\"$file?id=$a[id]&remove=POISTA\">POISTA</a>\n";
    }
  }
  echo "</TABLE>";
 } else {
  echo "<p>Plop. Ei kalustotietoja.";
 }

print "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: tavara.php,v 1.24 2009/10/05 11:43:10 riku Exp $ -->
